//
//  ViewController.m
//  VATPRC活动抽奖
//
//  Created by 马畅 on 15/5/29.
//  Copyright (c) 2015年 马畅. All rights reserved.
//

#import "ViewController.h"
#import <BmobSDK/Bmob.h>
#import "Info.h"
#import "MBProgressHUD.h"

NSString * const kUserListTableViewCellIdentifier = @"UserListTableViewCell";

@interface ViewController () <UITableViewDataSource,UITableViewDelegate> {
    NSMutableArray *_userArray;
    NSInteger _lotteryCount;
    BOOL _isNumThree;
    MBProgressHUD *_hud;
}

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self setupUserList];
    [self getUsers];
    _lotteryCount = 0;
    [_restartLottery setEnabled:NO];
    _isNumThree = NO;
    
    _hud = [[MBProgressHUD alloc] initWithView:self.view];
    _hud.labelText = @"正在随机抽取获奖者...";
    [self.view addSubview:_hud];
    // Do any additional setup after loading the view, typically from a nib.
}

- (void)setupUserList {
    _userList.delegate = self;
    _userList.dataSource = self;
}

- (void)getUsers {
    BmobQuery *bquery = [BmobQuery queryWithClassName:@"VATPRC"];
    [bquery orderByDescending:@"createdAt"];
    [bquery findObjectsInBackgroundWithBlock:^(NSArray *array, NSError *error) {
        if (!error) {
            if (!_userArray) {
                _userArray = [[NSMutableArray alloc] init];
            }
            _userArray = [array mutableCopy];
            [_userList reloadData];
        }
    }];
}
- (IBAction)restartLottery:(id)sender {
    [self getUsers];
    _isNumThree = NO;
    [_startLottery setTitle:@"开始第一轮"];
    [_startLottery setEnabled:YES];
    [_restartLottery setEnabled:NO];
}

- (IBAction)startLottery:(id)sender {
    [_hud show:YES];
    if (_lotteryCount == 0) {
        NSLog(@"开始第一轮");
        [_startLottery setTitle:@"开始第二轮"];
        [self startLotteryWithUsers:_userArray count:15];
        _lotteryCount ++;
    }
    else if (_lotteryCount == 1) {
        NSLog(@"开始第二轮");
        [_startLottery setTitle:@"开始第三轮"];
        [self startLotteryWithUsers:[Info defaultInfo].numOne count:10];
        _lotteryCount ++;
    }
    else if (_lotteryCount == 2) {
        NSLog(@"开始第三轮");
        [_startLottery setTitle:@"抽奖结束"];
        [_startLottery setEnabled:NO];
        [_restartLottery setEnabled:YES];
        _isNumThree = YES;
        [self startLotteryWithUsers:[Info defaultInfo].numTwo count:5];
        _lotteryCount = 0;
    }
    [self performSelector:@selector(reloadUserList) withObject:nil afterDelay:3.0f];
}

- (void)reloadUserList {
    [_userList reloadData];
}

//count为需要产生的获奖者数量，users为抽奖者名单
- (void)startLotteryWithUsers:(NSMutableArray *)users count:(NSInteger)count {
    NSMutableArray *result = [[NSMutableArray alloc] init];
    NSMutableArray *randomArray = [self getRandomArrayWithCount:count range:users.count];
    for (int i = 0; i < randomArray.count; i ++) {
        [result addObject:[users objectAtIndex:[[randomArray objectAtIndex:i] integerValue]]];
    }
//    NSLog(@"result = %@",result);
    if (_lotteryCount == 0) {
        [Info defaultInfo].numOne = [result mutableCopy];
    }
    else if (_lotteryCount == 1) {
        [Info defaultInfo].numTwo = [result mutableCopy];
    }
    else {
        [Info defaultInfo].numThree = [result mutableCopy];
        [self performSelector:@selector(showAlertViewWithResult:) withObject:result afterDelay:3.0f];
    }
    [_hud hide:YES afterDelay:3];
}

//count为需要产生的获奖者数量，range为产生随机数的范围
- (NSMutableArray *)getRandomArrayWithCount:(NSInteger)count range:(NSInteger)range{
    NSMutableArray *array = [[NSMutableArray alloc] init];
    for (int i = 0; i < count; i ++) {
        int x = arc4random() % range;
        NSString *randomStr = [NSString stringWithFormat:@"%d",x];
        if (![array containsObject:randomStr]) {
            [array addObject:randomStr];
            NSLog(@"num = %@",randomStr);
        }
        else {
            i --;
        }
    }
    return array;
}

- (void)showAlertViewWithResult:(NSMutableArray *)result {
    NSString *resultStr = [NSString stringWithFormat:@"获奖者:%@,\nVATSIM ID:%@,\nE-Mail:%@\n获奖者:%@,\nVATSIM ID:%@,\nE-Mail:%@\n获奖者:%@,\nVATSIM ID:%@,\nE-Mail:%@\n获奖者:%@,\nVATSIM ID:%@,\nE-Mail:%@\n获奖者:%@,\nVATSIM ID:%@,\nE-Mail:%@\n",[[result objectAtIndex:0] objectForKey:@"name"],[[result objectAtIndex:0] objectForKey:@"CID"],[[result objectAtIndex:0] objectForKey:@"email"],[[result objectAtIndex:1] objectForKey:@"name"],[[result objectAtIndex:1] objectForKey:@"CID"],[[result objectAtIndex:1] objectForKey:@"email"],[[result objectAtIndex:2] objectForKey:@"name"],[[result objectAtIndex:2] objectForKey:@"CID"],[[result objectAtIndex:2] objectForKey:@"email"],[[result objectAtIndex:3] objectForKey:@"name"],[[result objectAtIndex:3] objectForKey:@"CID"],[[result objectAtIndex:3] objectForKey:@"email"],[[result objectAtIndex:4] objectForKey:@"name"],[[result objectAtIndex:4] objectForKey:@"CID"],[[result objectAtIndex:4] objectForKey:@"email"]];
    NSLog(@"resultStr = %@",resultStr);
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"恭喜获奖！" message:resultStr delegate:self cancelButtonTitle:@"确定" otherButtonTitles:nil, nil];
    [alert show];
}

#pragma mark -- tableView 代理方法
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:kUserListTableViewCellIdentifier];
    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1 reuseIdentifier:kUserListTableViewCellIdentifier];
    }
    cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    cell.backgroundColor = [UIColor clearColor];
    cell.textLabel.textColor = [UIColor brownColor];
    cell.textLabel.text = [[_userArray objectAtIndex:indexPath.row] objectForKey:@"name"];
    cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[_userArray objectAtIndex:indexPath.row] objectForKey:@"CID"]];
    
    if (_lotteryCount == 0) {
        if (_isNumThree) {
            if (indexPath.section == 0) {
                cell.textLabel.text = [[[Info defaultInfo].numThree objectAtIndex:indexPath.row] objectForKey:@"name"];
                cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[[Info defaultInfo].numThree objectAtIndex:indexPath.row] objectForKey:@"CID"]];
            }
            else if (indexPath.section == 1) {
                cell.textLabel.text = [[[Info defaultInfo].numTwo objectAtIndex:indexPath.row] objectForKey:@"name"];
                cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[[Info defaultInfo].numTwo objectAtIndex:indexPath.row] objectForKey:@"CID"]];
            }
            else {
                cell.textLabel.text = [[[Info defaultInfo].numOne objectAtIndex:indexPath.row] objectForKey:@"name"];
                cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[[Info defaultInfo].numOne objectAtIndex:indexPath.row] objectForKey:@"CID"]];
            }
        }
        else {
            if (indexPath.section == 0) {
                cell.textLabel.text = [[_userArray objectAtIndex:indexPath.row] objectForKey:@"name"];
                cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[_userArray objectAtIndex:indexPath.row] objectForKey:@"CID"]];
            }
        }
    }
    else if (_lotteryCount == 1) {
        if (indexPath.section == 0) {
            cell.textLabel.text = [[[Info defaultInfo].numOne objectAtIndex:indexPath.row] objectForKey:@"name"];
            cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[[Info defaultInfo].numOne objectAtIndex:indexPath.row] objectForKey:@"CID"]];
        }
    }
    else if (_lotteryCount == 2) {
        if (indexPath.section == 0) {
            cell.textLabel.text = [[[Info defaultInfo].numTwo objectAtIndex:indexPath.row] objectForKey:@"name"];
            cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[[Info defaultInfo].numTwo objectAtIndex:indexPath.row] objectForKey:@"CID"]];
        }
        else {
            cell.textLabel.text = [[[Info defaultInfo].numOne objectAtIndex:indexPath.row] objectForKey:@"name"];
            cell.detailTextLabel.text = [NSString stringWithFormat:@"VATSIM ID:%@",[[[Info defaultInfo].numOne objectAtIndex:indexPath.row] objectForKey:@"CID"]];
        }
    }
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    return cell;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    NSInteger num = 0;
    if (_lotteryCount == 0) {
        if (_isNumThree) {
            if (section == 0) {
                num = [Info defaultInfo].numThree.count;
            }
            else if (section == 1) {
                num = [Info defaultInfo].numTwo.count;
            }
            else {
                num = [Info defaultInfo].numOne.count;
            }
        }
        else {
            if (section == 0) {
                num = _userArray.count;
            }
        }
    }
    else if (_lotteryCount == 1) {
        if (section == 0) {
            num = [Info defaultInfo].numOne.count;
        }
    }
    else if (_lotteryCount == 2) {
        if (section == 0) {
            num = [Info defaultInfo].numTwo.count;
        }
        else {
            num = [Info defaultInfo].numOne.count;
        }
    }
    return num;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    NSInteger num = 0;
    if (_lotteryCount == 0) {
        if (_isNumThree) {
            num = 3;
        }
        else {
            num = 1;
        }
    }
    else if (_lotteryCount == 1) {
        num = 1;
    }
    else if (_lotteryCount == 2) {
        num = 2;
    }
    return num;
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    NSString *header;
    if (_lotteryCount == 0) {
        if (_isNumThree) {
            if (section == 0) {
                header = @"第三轮结果";
            }
            else if (section == 1) {
                header = @"第二轮结果";
            }
            else {
                header = @"第一轮结果";
            }
        }
        else {
            if (section == 0) {
                header = @"参与用户";
            }
        }
    }
    else if (_lotteryCount == 1) {
        if (section == 0) {
            header = @"第一轮结果";
        }
    }
    else if (_lotteryCount == 2) {
        if (section == 0) {
            header = @"第二轮结果";
        }
        else if (section == 1) {
            header = @"第一轮结果";
        }
    }
    return header;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    return 30;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 20.f;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
